
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.protobuf import config_pb2 as tensorflow_dot_core_dot_protobuf_dot_config__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/compiler/jit/xla_activity.proto', package='tensorflow', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n*tensorflow/compiler/jit/xla_activity.proto\x12\ntensorflow\x1a%tensorflow/core/protobuf/config.proto"\x82\x03\n\x18XlaAutoClusteringSummary\x12\x1e\n\x16unclustered_node_count\x18\x01 \x01(\x05\x12\x1c\n\x14clustered_node_count\x18\x02 \x01(\x05\x12>\n\x08clusters\x18\x03 \x03(\x0b2,.tensorflow.XlaAutoClusteringSummary.Cluster\x12Q\n\x18unclustered_op_histogram\x18\x04 \x03(\x0b2/.tensorflow.XlaAutoClusteringSummary.OpAndCount\x1a\'\n\nOpAndCount\x12\n\n\x02op\x18\x01 \x01(\t\x12\r\n\x05count\x18\x02 \x01(\x05\x1al\n\x07Cluster\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\x05\x12E\n\x0cop_histogram\x18\x03 \x03(\x0b2/.tensorflow.XlaAutoClusteringSummary.OpAndCount"\xb9\x01\n\x19XlaAutoClusteringActivity\x12E\n\x10global_jit_level\x18\x01 \x01(\x0e2+.tensorflow.OptimizerOptions.GlobalJitLevel\x12\x1e\n\x16cpu_global_jit_enabled\x18\x02 \x01(\x08\x125\n\x07summary\x18\x03 \x01(\x0b2$.tensorflow.XlaAutoClusteringSummary"\x85\x01\n\x19XlaJitCompilationActivity\x12\x14\n\x0ccluster_name\x18\x01 \x01(\t\x12\x15\n\rcompile_count\x18\x02 \x01(\x05\x12\x17\n\x0fcompile_time_us\x18\x03 \x01(\x03\x12"\n\x1acumulative_compile_time_us\x18\x04 \x01(\x03"\x8b\x02\n\x15XlaOptimizationRemark\x12:\n\x07warning\x18\x01 \x01(\x0e2).tensorflow.XlaOptimizationRemark.Warning\x12\x19\n\x11debug_information\x18\x02 \x01(\t"\x9a\x01\n\x07Warning\x12\x08\n\x04NONE\x10\x00\x12\x18\n\x14INACCURATE_OPERATION\x10\x01\x12\x12\n\x0eSLOW_OPERATION\x10\x02\x12\x1b\n\x17UNIMPLEMENTED_OPERATION\x10\x03\x12 \n\x1cSLOW_IMAGE_RESIZE_DIMENSIONS\x10\x04\x12\x18\n\x14MEGAMORPHIC_FUNCTION\x10\x05b\x06proto3', dependencies=[tensorflow_dot_core_dot_protobuf_dot_config__pb2.DESCRIPTOR])
_XLAOPTIMIZATIONREMARK_WARNING = _descriptor.EnumDescriptor(name='Warning', full_name='tensorflow.XlaOptimizationRemark.Warning', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='NONE', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='INACCURATE_OPERATION', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='SLOW_OPERATION', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='UNIMPLEMENTED_OPERATION', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='SLOW_IMAGE_RESIZE_DIMENSIONS', index=4, number=4, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='MEGAMORPHIC_FUNCTION', index=5, number=5, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=924, serialized_end=1078)
_sym_db.RegisterEnumDescriptor(_XLAOPTIMIZATIONREMARK_WARNING)
_XLAAUTOCLUSTERINGSUMMARY_OPANDCOUNT = _descriptor.Descriptor(name='OpAndCount', full_name='tensorflow.XlaAutoClusteringSummary.OpAndCount', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='op', full_name='tensorflow.XlaAutoClusteringSummary.OpAndCount.op', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='count', full_name='tensorflow.XlaAutoClusteringSummary.OpAndCount.count', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=335, serialized_end=374)
_XLAAUTOCLUSTERINGSUMMARY_CLUSTER = _descriptor.Descriptor(name='Cluster', full_name='tensorflow.XlaAutoClusteringSummary.Cluster', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.XlaAutoClusteringSummary.Cluster.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='size', full_name='tensorflow.XlaAutoClusteringSummary.Cluster.size', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='op_histogram', full_name='tensorflow.XlaAutoClusteringSummary.Cluster.op_histogram', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=376, serialized_end=484)
_XLAAUTOCLUSTERINGSUMMARY = _descriptor.Descriptor(name='XlaAutoClusteringSummary', full_name='tensorflow.XlaAutoClusteringSummary', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='unclustered_node_count', full_name='tensorflow.XlaAutoClusteringSummary.unclustered_node_count', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='clustered_node_count', full_name='tensorflow.XlaAutoClusteringSummary.clustered_node_count', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='clusters', full_name='tensorflow.XlaAutoClusteringSummary.clusters', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='unclustered_op_histogram', full_name='tensorflow.XlaAutoClusteringSummary.unclustered_op_histogram', index=3, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_XLAAUTOCLUSTERINGSUMMARY_OPANDCOUNT, _XLAAUTOCLUSTERINGSUMMARY_CLUSTER], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=98, serialized_end=484)
_XLAAUTOCLUSTERINGACTIVITY = _descriptor.Descriptor(name='XlaAutoClusteringActivity', full_name='tensorflow.XlaAutoClusteringActivity', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='global_jit_level', full_name='tensorflow.XlaAutoClusteringActivity.global_jit_level', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cpu_global_jit_enabled', full_name='tensorflow.XlaAutoClusteringActivity.cpu_global_jit_enabled', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='summary', full_name='tensorflow.XlaAutoClusteringActivity.summary', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=487, serialized_end=672)
_XLAJITCOMPILATIONACTIVITY = _descriptor.Descriptor(name='XlaJitCompilationActivity', full_name='tensorflow.XlaJitCompilationActivity', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='cluster_name', full_name='tensorflow.XlaJitCompilationActivity.cluster_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='compile_count', full_name='tensorflow.XlaJitCompilationActivity.compile_count', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='compile_time_us', full_name='tensorflow.XlaJitCompilationActivity.compile_time_us', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cumulative_compile_time_us', full_name='tensorflow.XlaJitCompilationActivity.cumulative_compile_time_us', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=675, serialized_end=808)
_XLAOPTIMIZATIONREMARK = _descriptor.Descriptor(name='XlaOptimizationRemark', full_name='tensorflow.XlaOptimizationRemark', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='warning', full_name='tensorflow.XlaOptimizationRemark.warning', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='debug_information', full_name='tensorflow.XlaOptimizationRemark.debug_information', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[_XLAOPTIMIZATIONREMARK_WARNING], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=811, serialized_end=1078)
_XLAAUTOCLUSTERINGSUMMARY_OPANDCOUNT.containing_type = _XLAAUTOCLUSTERINGSUMMARY
_XLAAUTOCLUSTERINGSUMMARY_CLUSTER.fields_by_name['op_histogram'].message_type = _XLAAUTOCLUSTERINGSUMMARY_OPANDCOUNT
_XLAAUTOCLUSTERINGSUMMARY_CLUSTER.containing_type = _XLAAUTOCLUSTERINGSUMMARY
_XLAAUTOCLUSTERINGSUMMARY.fields_by_name['clusters'].message_type = _XLAAUTOCLUSTERINGSUMMARY_CLUSTER
_XLAAUTOCLUSTERINGSUMMARY.fields_by_name['unclustered_op_histogram'].message_type = _XLAAUTOCLUSTERINGSUMMARY_OPANDCOUNT
_XLAAUTOCLUSTERINGACTIVITY.fields_by_name['global_jit_level'].enum_type = tensorflow_dot_core_dot_protobuf_dot_config__pb2._OPTIMIZEROPTIONS_GLOBALJITLEVEL
_XLAAUTOCLUSTERINGACTIVITY.fields_by_name['summary'].message_type = _XLAAUTOCLUSTERINGSUMMARY
_XLAOPTIMIZATIONREMARK.fields_by_name['warning'].enum_type = _XLAOPTIMIZATIONREMARK_WARNING
_XLAOPTIMIZATIONREMARK_WARNING.containing_type = _XLAOPTIMIZATIONREMARK
DESCRIPTOR.message_types_by_name['XlaAutoClusteringSummary'] = _XLAAUTOCLUSTERINGSUMMARY
DESCRIPTOR.message_types_by_name['XlaAutoClusteringActivity'] = _XLAAUTOCLUSTERINGACTIVITY
DESCRIPTOR.message_types_by_name['XlaJitCompilationActivity'] = _XLAJITCOMPILATIONACTIVITY
DESCRIPTOR.message_types_by_name['XlaOptimizationRemark'] = _XLAOPTIMIZATIONREMARK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
XlaAutoClusteringSummary = _reflection.GeneratedProtocolMessageType('XlaAutoClusteringSummary', (_message.Message,), {'OpAndCount': _reflection.GeneratedProtocolMessageType('OpAndCount', (_message.Message,), {'DESCRIPTOR': _XLAAUTOCLUSTERINGSUMMARY_OPANDCOUNT, '__module__': 'tensorflow.compiler.jit.xla_activity_pb2'}), 'Cluster': _reflection.GeneratedProtocolMessageType('Cluster', (_message.Message,), {'DESCRIPTOR': _XLAAUTOCLUSTERINGSUMMARY_CLUSTER, '__module__': 'tensorflow.compiler.jit.xla_activity_pb2'}), 'DESCRIPTOR': _XLAAUTOCLUSTERINGSUMMARY, '__module__': 'tensorflow.compiler.jit.xla_activity_pb2'})
_sym_db.RegisterMessage(XlaAutoClusteringSummary)
_sym_db.RegisterMessage(XlaAutoClusteringSummary.OpAndCount)
_sym_db.RegisterMessage(XlaAutoClusteringSummary.Cluster)
XlaAutoClusteringActivity = _reflection.GeneratedProtocolMessageType('XlaAutoClusteringActivity', (_message.Message,), {'DESCRIPTOR': _XLAAUTOCLUSTERINGACTIVITY, '__module__': 'tensorflow.compiler.jit.xla_activity_pb2'})
_sym_db.RegisterMessage(XlaAutoClusteringActivity)
XlaJitCompilationActivity = _reflection.GeneratedProtocolMessageType('XlaJitCompilationActivity', (_message.Message,), {'DESCRIPTOR': _XLAJITCOMPILATIONACTIVITY, '__module__': 'tensorflow.compiler.jit.xla_activity_pb2'})
_sym_db.RegisterMessage(XlaJitCompilationActivity)
XlaOptimizationRemark = _reflection.GeneratedProtocolMessageType('XlaOptimizationRemark', (_message.Message,), {'DESCRIPTOR': _XLAOPTIMIZATIONREMARK, '__module__': 'tensorflow.compiler.jit.xla_activity_pb2'})
_sym_db.RegisterMessage(XlaOptimizationRemark)




'Generated protocol buffer code.'
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/hardware_types.proto', package='tensorflow.profiler', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n6tensorflow/core/profiler/protobuf/hardware_types.proto\x12\x13tensorflow.profiler"5\n\x15CudaComputeCapability\x12\r\n\x05major\x18\x01 \x01(\r\x12\r\n\x05minor\x18\x02 \x01(\r"\xc2\x01\n\x12DeviceCapabilities\x12\x19\n\x11clock_rate_in_ghz\x18\x01 \x01(\x01\x12\x11\n\tnum_cores\x18\x02 \x01(\r\x12\x1c\n\x14memory_size_in_bytes\x18\x03 \x01(\x04\x12\x18\n\x10memory_bandwidth\x18\x04 \x01(\x04\x12F\n\x12compute_capability\x18\x05 \x01(\x0b2*.tensorflow.profiler.CudaComputeCapability*D\n\x0cHardwareType\x12\x14\n\x10UNKNOWN_HARDWARE\x10\x00\x12\x0c\n\x08CPU_ONLY\x10\x01\x12\x07\n\x03GPU\x10\x02\x12\x07\n\x03TPU\x10\x03b\x06proto3')
_HARDWARETYPE = _descriptor.EnumDescriptor(name='HardwareType', full_name='tensorflow.profiler.HardwareType', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='UNKNOWN_HARDWARE', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='CPU_ONLY', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='GPU', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TPU', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=331, serialized_end=399)
_sym_db.RegisterEnumDescriptor(_HARDWARETYPE)
HardwareType = enum_type_wrapper.EnumTypeWrapper(_HARDWARETYPE)
UNKNOWN_HARDWARE = 0
CPU_ONLY = 1
GPU = 2
TPU = 3
_CUDACOMPUTECAPABILITY = _descriptor.Descriptor(name='CudaComputeCapability', full_name='tensorflow.profiler.CudaComputeCapability', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='major', full_name='tensorflow.profiler.CudaComputeCapability.major', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='minor', full_name='tensorflow.profiler.CudaComputeCapability.minor', index=1, number=2, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=79, serialized_end=132)
_DEVICECAPABILITIES = _descriptor.Descriptor(name='DeviceCapabilities', full_name='tensorflow.profiler.DeviceCapabilities', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='clock_rate_in_ghz', full_name='tensorflow.profiler.DeviceCapabilities.clock_rate_in_ghz', index=0, number=1, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_cores', full_name='tensorflow.profiler.DeviceCapabilities.num_cores', index=1, number=2, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='memory_size_in_bytes', full_name='tensorflow.profiler.DeviceCapabilities.memory_size_in_bytes', index=2, number=3, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='memory_bandwidth', full_name='tensorflow.profiler.DeviceCapabilities.memory_bandwidth', index=3, number=4, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='compute_capability', full_name='tensorflow.profiler.DeviceCapabilities.compute_capability', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=135, serialized_end=329)
_DEVICECAPABILITIES.fields_by_name['compute_capability'].message_type = _CUDACOMPUTECAPABILITY
DESCRIPTOR.message_types_by_name['CudaComputeCapability'] = _CUDACOMPUTECAPABILITY
DESCRIPTOR.message_types_by_name['DeviceCapabilities'] = _DEVICECAPABILITIES
DESCRIPTOR.enum_types_by_name['HardwareType'] = _HARDWARETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
CudaComputeCapability = _reflection.GeneratedProtocolMessageType('CudaComputeCapability', (_message.Message,), {'DESCRIPTOR': _CUDACOMPUTECAPABILITY, '__module__': 'tensorflow.core.profiler.protobuf.hardware_types_pb2'})
_sym_db.RegisterMessage(CudaComputeCapability)
DeviceCapabilities = _reflection.GeneratedProtocolMessageType('DeviceCapabilities', (_message.Message,), {'DESCRIPTOR': _DEVICECAPABILITIES, '__module__': 'tensorflow.core.profiler.protobuf.hardware_types_pb2'})
_sym_db.RegisterMessage(DeviceCapabilities)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import full_type_pb2 as tensorflow_dot_core_dot_framework_dot_full__type__pb2
from ....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from ....tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/python/framework/cpp_shape_inference.proto', package='tensorflow', syntax='proto3', serialized_options=b'Z\\github.com/tensorflow/tensorflow/tensorflow/go/python/framework/cpp_shape_inference_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n5tensorflow/python/framework/cpp_shape_inference.proto\x12\ntensorflow\x1a)tensorflow/core/framework/full_type.proto\x1a,tensorflow/core/framework/tensor_shape.proto\x1a%tensorflow/core/framework/types.proto"\x9b\x03\n\x17CppShapeInferenceResult\x12+\n\x05shape\x18\x01 \x01(\x0b2\x1c.tensorflow.TensorShapeProto\x12C\n\x0bhandle_data\x18\x04 \x01(\x0b2..tensorflow.CppShapeInferenceResult.HandleData\x1a\x93\x01\n\x12HandleShapeAndType\x12+\n\x05shape\x18\x01 \x01(\x0b2\x1c.tensorflow.TensorShapeProto\x12#\n\x05dtype\x18\x02 \x01(\x0e2\x14.tensorflow.DataType\x12%\n\x04type\x18\x04 \x01(\x0b2\x17.tensorflow.FullTypeDefJ\x04\x08\x03\x10\x04\x1al\n\nHandleData\x12\x0e\n\x06is_set\x18\x01 \x01(\x08\x12N\n\x0eshape_and_type\x18\x02 \x03(\x0b26.tensorflow.CppShapeInferenceResult.HandleShapeAndTypeJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04"e\n\x1dCppShapeInferenceInputsNeeded\x12\x1c\n\x14input_tensors_needed\x18\x01 \x03(\x05\x12&\n\x1einput_tensors_as_shapes_needed\x18\x02 \x03(\x05BaZ\\github.com/tensorflow/tensorflow/tensorflow/go/python/framework/cpp_shape_inference_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_full__type__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR])
_CPPSHAPEINFERENCERESULT_HANDLESHAPEANDTYPE = _descriptor.Descriptor(name='HandleShapeAndType', full_name='tensorflow.CppShapeInferenceResult.HandleShapeAndType', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='shape', full_name='tensorflow.CppShapeInferenceResult.HandleShapeAndType.shape', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dtype', full_name='tensorflow.CppShapeInferenceResult.HandleShapeAndType.dtype', index=1, number=2, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='type', full_name='tensorflow.CppShapeInferenceResult.HandleShapeAndType.type', index=2, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=340, serialized_end=487)
_CPPSHAPEINFERENCERESULT_HANDLEDATA = _descriptor.Descriptor(name='HandleData', full_name='tensorflow.CppShapeInferenceResult.HandleData', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='is_set', full_name='tensorflow.CppShapeInferenceResult.HandleData.is_set', index=0, number=1, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape_and_type', full_name='tensorflow.CppShapeInferenceResult.HandleData.shape_and_type', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=489, serialized_end=597)
_CPPSHAPEINFERENCERESULT = _descriptor.Descriptor(name='CppShapeInferenceResult', full_name='tensorflow.CppShapeInferenceResult', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='shape', full_name='tensorflow.CppShapeInferenceResult.shape', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='handle_data', full_name='tensorflow.CppShapeInferenceResult.handle_data', index=1, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_CPPSHAPEINFERENCERESULT_HANDLESHAPEANDTYPE, _CPPSHAPEINFERENCERESULT_HANDLEDATA], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=198, serialized_end=609)
_CPPSHAPEINFERENCEINPUTSNEEDED = _descriptor.Descriptor(name='CppShapeInferenceInputsNeeded', full_name='tensorflow.CppShapeInferenceInputsNeeded', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='input_tensors_needed', full_name='tensorflow.CppShapeInferenceInputsNeeded.input_tensors_needed', index=0, number=1, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_tensors_as_shapes_needed', full_name='tensorflow.CppShapeInferenceInputsNeeded.input_tensors_as_shapes_needed', index=1, number=2, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=611, serialized_end=712)
_CPPSHAPEINFERENCERESULT_HANDLESHAPEANDTYPE.fields_by_name['shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_CPPSHAPEINFERENCERESULT_HANDLESHAPEANDTYPE.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_CPPSHAPEINFERENCERESULT_HANDLESHAPEANDTYPE.fields_by_name['type'].message_type = tensorflow_dot_core_dot_framework_dot_full__type__pb2._FULLTYPEDEF
_CPPSHAPEINFERENCERESULT_HANDLESHAPEANDTYPE.containing_type = _CPPSHAPEINFERENCERESULT
_CPPSHAPEINFERENCERESULT_HANDLEDATA.fields_by_name['shape_and_type'].message_type = _CPPSHAPEINFERENCERESULT_HANDLESHAPEANDTYPE
_CPPSHAPEINFERENCERESULT_HANDLEDATA.containing_type = _CPPSHAPEINFERENCERESULT
_CPPSHAPEINFERENCERESULT.fields_by_name['shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_CPPSHAPEINFERENCERESULT.fields_by_name['handle_data'].message_type = _CPPSHAPEINFERENCERESULT_HANDLEDATA
DESCRIPTOR.message_types_by_name['CppShapeInferenceResult'] = _CPPSHAPEINFERENCERESULT
DESCRIPTOR.message_types_by_name['CppShapeInferenceInputsNeeded'] = _CPPSHAPEINFERENCEINPUTSNEEDED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
CppShapeInferenceResult = _reflection.GeneratedProtocolMessageType('CppShapeInferenceResult', (_message.Message,), {'HandleShapeAndType': _reflection.GeneratedProtocolMessageType('HandleShapeAndType', (_message.Message,), {'DESCRIPTOR': _CPPSHAPEINFERENCERESULT_HANDLESHAPEANDTYPE, '__module__': 'tensorflow.python.framework.cpp_shape_inference_pb2'}), 'HandleData': _reflection.GeneratedProtocolMessageType('HandleData', (_message.Message,), {'DESCRIPTOR': _CPPSHAPEINFERENCERESULT_HANDLEDATA, '__module__': 'tensorflow.python.framework.cpp_shape_inference_pb2'}), 'DESCRIPTOR': _CPPSHAPEINFERENCERESULT, '__module__': 'tensorflow.python.framework.cpp_shape_inference_pb2'})
_sym_db.RegisterMessage(CppShapeInferenceResult)
_sym_db.RegisterMessage(CppShapeInferenceResult.HandleShapeAndType)
_sym_db.RegisterMessage(CppShapeInferenceResult.HandleData)
CppShapeInferenceInputsNeeded = _reflection.GeneratedProtocolMessageType('CppShapeInferenceInputsNeeded', (_message.Message,), {'DESCRIPTOR': _CPPSHAPEINFERENCEINPUTSNEEDED, '__module__': 'tensorflow.python.framework.cpp_shape_inference_pb2'})
_sym_db.RegisterMessage(CppShapeInferenceInputsNeeded)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from ....tensorflow.core.framework import tensor_slice_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__slice__pb2
from ....tensorflow.core.framework import tensor_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__pb2
from ....tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2
from ....tensorflow.core.framework import versions_pb2 as tensorflow_dot_core_dot_framework_dot_versions__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/util/saved_tensor_slice.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x13org.tensorflow.utilB\x16SavedTensorSliceProtosP\x01\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n-tensorflow/core/util/saved_tensor_slice.proto\x12\ntensorflow\x1a,tensorflow/core/framework/tensor_shape.proto\x1a,tensorflow/core/framework/tensor_slice.proto\x1a&tensorflow/core/framework/tensor.proto\x1a%tensorflow/core/framework/types.proto\x1a(tensorflow/core/framework/versions.proto"\x9c\x01\n\x0eSavedSliceMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12+\n\x05shape\x18\x02 \x01(\x0b2\x1c.tensorflow.TensorShapeProto\x12"\n\x04type\x18\x03 \x01(\x0e2\x14.tensorflow.DataType\x12+\n\x05slice\x18\x04 \x03(\x0b2\x1c.tensorflow.TensorSliceProto"l\n\x14SavedTensorSliceMeta\x12*\n\x06tensor\x18\x01 \x03(\x0b2\x1a.tensorflow.SavedSliceMeta\x12(\n\x08versions\x18\x02 \x01(\x0b2\x16.tensorflow.VersionDef"n\n\nSavedSlice\x12\x0c\n\x04name\x18\x01 \x01(\t\x12+\n\x05slice\x18\x02 \x01(\x0b2\x1c.tensorflow.TensorSliceProto\x12%\n\x04data\x18\x03 \x01(\x0b2\x17.tensorflow.TensorProto"i\n\x11SavedTensorSlices\x12.\n\x04meta\x18\x01 \x01(\x0b2 .tensorflow.SavedTensorSliceMeta\x12$\n\x04data\x18\x02 \x01(\x0b2\x16.tensorflow.SavedSliceB2\n\x13org.tensorflow.utilB\x16SavedTensorSliceProtosP\x01\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__slice__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_versions__pb2.DESCRIPTOR])
_SAVEDSLICEMETA = _descriptor.Descriptor(name='SavedSliceMeta', full_name='tensorflow.SavedSliceMeta', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.SavedSliceMeta.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tensorflow.SavedSliceMeta.shape', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='type', full_name='tensorflow.SavedSliceMeta.type', index=2, number=3, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='slice', full_name='tensorflow.SavedSliceMeta.slice', index=3, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=275, serialized_end=431)
_SAVEDTENSORSLICEMETA = _descriptor.Descriptor(name='SavedTensorSliceMeta', full_name='tensorflow.SavedTensorSliceMeta', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='tensor', full_name='tensorflow.SavedTensorSliceMeta.tensor', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='versions', full_name='tensorflow.SavedTensorSliceMeta.versions', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=433, serialized_end=541)
_SAVEDSLICE = _descriptor.Descriptor(name='SavedSlice', full_name='tensorflow.SavedSlice', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.SavedSlice.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='slice', full_name='tensorflow.SavedSlice.slice', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='data', full_name='tensorflow.SavedSlice.data', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=543, serialized_end=653)
_SAVEDTENSORSLICES = _descriptor.Descriptor(name='SavedTensorSlices', full_name='tensorflow.SavedTensorSlices', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='meta', full_name='tensorflow.SavedTensorSlices.meta', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='data', full_name='tensorflow.SavedTensorSlices.data', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=655, serialized_end=760)
_SAVEDSLICEMETA.fields_by_name['shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_SAVEDSLICEMETA.fields_by_name['type'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_SAVEDSLICEMETA.fields_by_name['slice'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__slice__pb2._TENSORSLICEPROTO
_SAVEDTENSORSLICEMETA.fields_by_name['tensor'].message_type = _SAVEDSLICEMETA
_SAVEDTENSORSLICEMETA.fields_by_name['versions'].message_type = tensorflow_dot_core_dot_framework_dot_versions__pb2._VERSIONDEF
_SAVEDSLICE.fields_by_name['slice'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__slice__pb2._TENSORSLICEPROTO
_SAVEDSLICE.fields_by_name['data'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_SAVEDTENSORSLICES.fields_by_name['meta'].message_type = _SAVEDTENSORSLICEMETA
_SAVEDTENSORSLICES.fields_by_name['data'].message_type = _SAVEDSLICE
DESCRIPTOR.message_types_by_name['SavedSliceMeta'] = _SAVEDSLICEMETA
DESCRIPTOR.message_types_by_name['SavedTensorSliceMeta'] = _SAVEDTENSORSLICEMETA
DESCRIPTOR.message_types_by_name['SavedSlice'] = _SAVEDSLICE
DESCRIPTOR.message_types_by_name['SavedTensorSlices'] = _SAVEDTENSORSLICES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
SavedSliceMeta = _reflection.GeneratedProtocolMessageType('SavedSliceMeta', (_message.Message,), {'DESCRIPTOR': _SAVEDSLICEMETA, '__module__': 'tensorflow.core.util.saved_tensor_slice_pb2'})
_sym_db.RegisterMessage(SavedSliceMeta)
SavedTensorSliceMeta = _reflection.GeneratedProtocolMessageType('SavedTensorSliceMeta', (_message.Message,), {'DESCRIPTOR': _SAVEDTENSORSLICEMETA, '__module__': 'tensorflow.core.util.saved_tensor_slice_pb2'})
_sym_db.RegisterMessage(SavedTensorSliceMeta)
SavedSlice = _reflection.GeneratedProtocolMessageType('SavedSlice', (_message.Message,), {'DESCRIPTOR': _SAVEDSLICE, '__module__': 'tensorflow.core.util.saved_tensor_slice_pb2'})
_sym_db.RegisterMessage(SavedSlice)
SavedTensorSlices = _reflection.GeneratedProtocolMessageType('SavedTensorSlices', (_message.Message,), {'DESCRIPTOR': _SAVEDTENSORSLICES, '__module__': 'tensorflow.core.util.saved_tensor_slice_pb2'})
_sym_db.RegisterMessage(SavedTensorSlices)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/lite/tools/evaluation/proto/preprocessing_steps.proto', package='tflite.evaluation', syntax='proto2', serialized_options=b'\n\x11tflite.evaluationP\x01\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n@tensorflow/lite/tools/evaluation/proto/preprocessing_steps.proto\x12\x11tflite.evaluation"\xa8\x02\n\x1cImagePreprocessingStepParams\x12<\n\x0fcropping_params\x18\x01 \x01(\x0b2!.tflite.evaluation.CroppingParamsH\x00\x12<\n\x0fresizing_params\x18\x02 \x01(\x0b2!.tflite.evaluation.ResizingParamsH\x00\x12:\n\x0epadding_params\x18\x03 \x01(\x0b2 .tflite.evaluation.PaddingParamsH\x00\x12F\n\x14normalization_params\x18\x04 \x01(\x0b2&.tflite.evaluation.NormalizationParamsH\x00B\x08\n\x06params"*\n\tImageSize\x12\r\n\x05width\x18\x01 \x02(\r\x12\x0e\n\x06height\x18\x02 \x02(\r"\x8c\x01\n\x0eCroppingParams\x12"\n\x11cropping_fraction\x18\x01 \x01(\x02:\x050.875H\x00\x123\n\x0btarget_size\x18\x02 \x01(\x0b2\x1c.tflite.evaluation.ImageSizeH\x00\x12\x17\n\x0fsquare_cropping\x18\x03 \x01(\x08B\x08\n\x06params"^\n\x0eResizingParams\x121\n\x0btarget_size\x18\x01 \x02(\x0b2\x1c.tflite.evaluation.ImageSize\x12\x19\n\x11aspect_preserving\x18\x02 \x02(\x08"\x7f\n\rPaddingParams\x123\n\x0btarget_size\x18\x01 \x01(\x0b2\x1c.tflite.evaluation.ImageSizeH\x00\x12\x18\n\x0esquare_padding\x18\x02 \x01(\x08H\x00\x12\x15\n\rpadding_value\x18\x03 \x02(\x05B\x08\n\x06params"\xe1\x01\n\x13NormalizationParams\x12\x1a\n\x10channelwise_mean\x18\x01 \x01(\x02H\x00\x12L\n\x05means\x18\x02 \x01(\x0b2;.tflite.evaluation.NormalizationParams.PerChannelMeanValuesH\x00\x12\x10\n\x05scale\x18\x03 \x02(\x02:\x011\x1aF\n\x14PerChannelMeanValues\x12\x0e\n\x06r_mean\x18\x01 \x02(\x02\x12\x0e\n\x06g_mean\x18\x02 \x02(\x02\x12\x0e\n\x06b_mean\x18\x03 \x02(\x02B\x06\n\x04meanB\x18\n\x11tflite.evaluationP\x01\xf8\x01\x01')
_IMAGEPREPROCESSINGSTEPPARAMS = _descriptor.Descriptor(name='ImagePreprocessingStepParams', full_name='tflite.evaluation.ImagePreprocessingStepParams', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='cropping_params', full_name='tflite.evaluation.ImagePreprocessingStepParams.cropping_params', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='resizing_params', full_name='tflite.evaluation.ImagePreprocessingStepParams.resizing_params', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='padding_params', full_name='tflite.evaluation.ImagePreprocessingStepParams.padding_params', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='normalization_params', full_name='tflite.evaluation.ImagePreprocessingStepParams.normalization_params', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='params', full_name='tflite.evaluation.ImagePreprocessingStepParams.params', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=88, serialized_end=384)
_IMAGESIZE = _descriptor.Descriptor(name='ImageSize', full_name='tflite.evaluation.ImageSize', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='width', full_name='tflite.evaluation.ImageSize.width', index=0, number=1, type=13, cpp_type=3, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='height', full_name='tflite.evaluation.ImageSize.height', index=1, number=2, type=13, cpp_type=3, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=386, serialized_end=428)
_CROPPINGPARAMS = _descriptor.Descriptor(name='CroppingParams', full_name='tflite.evaluation.CroppingParams', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='cropping_fraction', full_name='tflite.evaluation.CroppingParams.cropping_fraction', index=0, number=1, type=2, cpp_type=6, label=1, has_default_value=True, default_value=float(0.875), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='target_size', full_name='tflite.evaluation.CroppingParams.target_size', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='square_cropping', full_name='tflite.evaluation.CroppingParams.square_cropping', index=2, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='params', full_name='tflite.evaluation.CroppingParams.params', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=431, serialized_end=571)
_RESIZINGPARAMS = _descriptor.Descriptor(name='ResizingParams', full_name='tflite.evaluation.ResizingParams', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='target_size', full_name='tflite.evaluation.ResizingParams.target_size', index=0, number=1, type=11, cpp_type=10, label=2, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='aspect_preserving', full_name='tflite.evaluation.ResizingParams.aspect_preserving', index=1, number=2, type=8, cpp_type=7, label=2, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=573, serialized_end=667)
_PADDINGPARAMS = _descriptor.Descriptor(name='PaddingParams', full_name='tflite.evaluation.PaddingParams', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='target_size', full_name='tflite.evaluation.PaddingParams.target_size', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='square_padding', full_name='tflite.evaluation.PaddingParams.square_padding', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='padding_value', full_name='tflite.evaluation.PaddingParams.padding_value', index=2, number=3, type=5, cpp_type=1, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='params', full_name='tflite.evaluation.PaddingParams.params', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=669, serialized_end=796)
_NORMALIZATIONPARAMS_PERCHANNELMEANVALUES = _descriptor.Descriptor(name='PerChannelMeanValues', full_name='tflite.evaluation.NormalizationParams.PerChannelMeanValues', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='r_mean', full_name='tflite.evaluation.NormalizationParams.PerChannelMeanValues.r_mean', index=0, number=1, type=2, cpp_type=6, label=2, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='g_mean', full_name='tflite.evaluation.NormalizationParams.PerChannelMeanValues.g_mean', index=1, number=2, type=2, cpp_type=6, label=2, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='b_mean', full_name='tflite.evaluation.NormalizationParams.PerChannelMeanValues.b_mean', index=2, number=3, type=2, cpp_type=6, label=2, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=946, serialized_end=1016)
_NORMALIZATIONPARAMS = _descriptor.Descriptor(name='NormalizationParams', full_name='tflite.evaluation.NormalizationParams', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='channelwise_mean', full_name='tflite.evaluation.NormalizationParams.channelwise_mean', index=0, number=1, type=2, cpp_type=6, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='means', full_name='tflite.evaluation.NormalizationParams.means', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='scale', full_name='tflite.evaluation.NormalizationParams.scale', index=2, number=3, type=2, cpp_type=6, label=2, has_default_value=True, default_value=float(1), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_NORMALIZATIONPARAMS_PERCHANNELMEANVALUES], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='mean', full_name='tflite.evaluation.NormalizationParams.mean', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=799, serialized_end=1024)
_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['cropping_params'].message_type = _CROPPINGPARAMS
_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['resizing_params'].message_type = _RESIZINGPARAMS
_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['padding_params'].message_type = _PADDINGPARAMS
_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['normalization_params'].message_type = _NORMALIZATIONPARAMS
_IMAGEPREPROCESSINGSTEPPARAMS.oneofs_by_name['params'].fields.append(_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['cropping_params'])
_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['cropping_params'].containing_oneof = _IMAGEPREPROCESSINGSTEPPARAMS.oneofs_by_name['params']
_IMAGEPREPROCESSINGSTEPPARAMS.oneofs_by_name['params'].fields.append(_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['resizing_params'])
_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['resizing_params'].containing_oneof = _IMAGEPREPROCESSINGSTEPPARAMS.oneofs_by_name['params']
_IMAGEPREPROCESSINGSTEPPARAMS.oneofs_by_name['params'].fields.append(_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['padding_params'])
_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['padding_params'].containing_oneof = _IMAGEPREPROCESSINGSTEPPARAMS.oneofs_by_name['params']
_IMAGEPREPROCESSINGSTEPPARAMS.oneofs_by_name['params'].fields.append(_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['normalization_params'])
_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['normalization_params'].containing_oneof = _IMAGEPREPROCESSINGSTEPPARAMS.oneofs_by_name['params']
_CROPPINGPARAMS.fields_by_name['target_size'].message_type = _IMAGESIZE
_CROPPINGPARAMS.oneofs_by_name['params'].fields.append(_CROPPINGPARAMS.fields_by_name['cropping_fraction'])
_CROPPINGPARAMS.fields_by_name['cropping_fraction'].containing_oneof = _CROPPINGPARAMS.oneofs_by_name['params']
_CROPPINGPARAMS.oneofs_by_name['params'].fields.append(_CROPPINGPARAMS.fields_by_name['target_size'])
_CROPPINGPARAMS.fields_by_name['target_size'].containing_oneof = _CROPPINGPARAMS.oneofs_by_name['params']
_RESIZINGPARAMS.fields_by_name['target_size'].message_type = _IMAGESIZE
_PADDINGPARAMS.fields_by_name['target_size'].message_type = _IMAGESIZE
_PADDINGPARAMS.oneofs_by_name['params'].fields.append(_PADDINGPARAMS.fields_by_name['target_size'])
_PADDINGPARAMS.fields_by_name['target_size'].containing_oneof = _PADDINGPARAMS.oneofs_by_name['params']
_PADDINGPARAMS.oneofs_by_name['params'].fields.append(_PADDINGPARAMS.fields_by_name['square_padding'])
_PADDINGPARAMS.fields_by_name['square_padding'].containing_oneof = _PADDINGPARAMS.oneofs_by_name['params']
_NORMALIZATIONPARAMS_PERCHANNELMEANVALUES.containing_type = _NORMALIZATIONPARAMS
_NORMALIZATIONPARAMS.fields_by_name['means'].message_type = _NORMALIZATIONPARAMS_PERCHANNELMEANVALUES
_NORMALIZATIONPARAMS.oneofs_by_name['mean'].fields.append(_NORMALIZATIONPARAMS.fields_by_name['channelwise_mean'])
_NORMALIZATIONPARAMS.fields_by_name['channelwise_mean'].containing_oneof = _NORMALIZATIONPARAMS.oneofs_by_name['mean']
_NORMALIZATIONPARAMS.oneofs_by_name['mean'].fields.append(_NORMALIZATIONPARAMS.fields_by_name['means'])
_NORMALIZATIONPARAMS.fields_by_name['means'].containing_oneof = _NORMALIZATIONPARAMS.oneofs_by_name['mean']
DESCRIPTOR.message_types_by_name['ImagePreprocessingStepParams'] = _IMAGEPREPROCESSINGSTEPPARAMS
DESCRIPTOR.message_types_by_name['ImageSize'] = _IMAGESIZE
DESCRIPTOR.message_types_by_name['CroppingParams'] = _CROPPINGPARAMS
DESCRIPTOR.message_types_by_name['ResizingParams'] = _RESIZINGPARAMS
DESCRIPTOR.message_types_by_name['PaddingParams'] = _PADDINGPARAMS
DESCRIPTOR.message_types_by_name['NormalizationParams'] = _NORMALIZATIONPARAMS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
ImagePreprocessingStepParams = _reflection.GeneratedProtocolMessageType('ImagePreprocessingStepParams', (_message.Message,), {'DESCRIPTOR': _IMAGEPREPROCESSINGSTEPPARAMS, '__module__': 'tensorflow.lite.tools.evaluation.proto.preprocessing_steps_pb2'})
_sym_db.RegisterMessage(ImagePreprocessingStepParams)
ImageSize = _reflection.GeneratedProtocolMessageType('ImageSize', (_message.Message,), {'DESCRIPTOR': _IMAGESIZE, '__module__': 'tensorflow.lite.tools.evaluation.proto.preprocessing_steps_pb2'})
_sym_db.RegisterMessage(ImageSize)
CroppingParams = _reflection.GeneratedProtocolMessageType('CroppingParams', (_message.Message,), {'DESCRIPTOR': _CROPPINGPARAMS, '__module__': 'tensorflow.lite.tools.evaluation.proto.preprocessing_steps_pb2'})
_sym_db.RegisterMessage(CroppingParams)
ResizingParams = _reflection.GeneratedProtocolMessageType('ResizingParams', (_message.Message,), {'DESCRIPTOR': _RESIZINGPARAMS, '__module__': 'tensorflow.lite.tools.evaluation.proto.preprocessing_steps_pb2'})
_sym_db.RegisterMessage(ResizingParams)
PaddingParams = _reflection.GeneratedProtocolMessageType('PaddingParams', (_message.Message,), {'DESCRIPTOR': _PADDINGPARAMS, '__module__': 'tensorflow.lite.tools.evaluation.proto.preprocessing_steps_pb2'})
_sym_db.RegisterMessage(PaddingParams)
NormalizationParams = _reflection.GeneratedProtocolMessageType('NormalizationParams', (_message.Message,), {'PerChannelMeanValues': _reflection.GeneratedProtocolMessageType('PerChannelMeanValues', (_message.Message,), {'DESCRIPTOR': _NORMALIZATIONPARAMS_PERCHANNELMEANVALUES, '__module__': 'tensorflow.lite.tools.evaluation.proto.preprocessing_steps_pb2'}), 'DESCRIPTOR': _NORMALIZATIONPARAMS, '__module__': 'tensorflow.lite.tools.evaluation.proto.preprocessing_steps_pb2'})
_sym_db.RegisterMessage(NormalizationParams)
_sym_db.RegisterMessage(NormalizationParams.PerChannelMeanValues)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ......tensorflow.lite.tools.evaluation.proto import evaluation_stages_pb2 as tensorflow_dot_lite_dot_tools_dot_evaluation_dot_proto_dot_evaluation__stages__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/lite/tools/evaluation/proto/evaluation_config.proto', package='tflite.evaluation', syntax='proto2', serialized_options=b'\n\x11tflite.evaluationP\x01\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n>tensorflow/lite/tools/evaluation/proto/evaluation_config.proto\x12\x11tflite.evaluation\x1a>tensorflow/lite/tools/evaluation/proto/evaluation_stages.proto"e\n\x15EvaluationStageConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12>\n\rspecification\x18\x02 \x01(\x0b2\'.tflite.evaluation.ProcessSpecification"f\n\x16EvaluationStageMetrics\x12\x10\n\x08num_runs\x18\x01 \x01(\x05\x12:\n\x0fprocess_metrics\x18\x02 \x01(\x0b2!.tflite.evaluation.ProcessMetricsB\x18\n\x11tflite.evaluationP\x01\xf8\x01\x01', dependencies=[tensorflow_dot_lite_dot_tools_dot_evaluation_dot_proto_dot_evaluation__stages__pb2.DESCRIPTOR])
_EVALUATIONSTAGECONFIG = _descriptor.Descriptor(name='EvaluationStageConfig', full_name='tflite.evaluation.EvaluationStageConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tflite.evaluation.EvaluationStageConfig.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='specification', full_name='tflite.evaluation.EvaluationStageConfig.specification', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=149, serialized_end=250)
_EVALUATIONSTAGEMETRICS = _descriptor.Descriptor(name='EvaluationStageMetrics', full_name='tflite.evaluation.EvaluationStageMetrics', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='num_runs', full_name='tflite.evaluation.EvaluationStageMetrics.num_runs', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='process_metrics', full_name='tflite.evaluation.EvaluationStageMetrics.process_metrics', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=252, serialized_end=354)
_EVALUATIONSTAGECONFIG.fields_by_name['specification'].message_type = tensorflow_dot_lite_dot_tools_dot_evaluation_dot_proto_dot_evaluation__stages__pb2._PROCESSSPECIFICATION
_EVALUATIONSTAGEMETRICS.fields_by_name['process_metrics'].message_type = tensorflow_dot_lite_dot_tools_dot_evaluation_dot_proto_dot_evaluation__stages__pb2._PROCESSMETRICS
DESCRIPTOR.message_types_by_name['EvaluationStageConfig'] = _EVALUATIONSTAGECONFIG
DESCRIPTOR.message_types_by_name['EvaluationStageMetrics'] = _EVALUATIONSTAGEMETRICS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
EvaluationStageConfig = _reflection.GeneratedProtocolMessageType('EvaluationStageConfig', (_message.Message,), {'DESCRIPTOR': _EVALUATIONSTAGECONFIG, '__module__': 'tensorflow.lite.tools.evaluation.proto.evaluation_config_pb2'})
_sym_db.RegisterMessage(EvaluationStageConfig)
EvaluationStageMetrics = _reflection.GeneratedProtocolMessageType('EvaluationStageMetrics', (_message.Message,), {'DESCRIPTOR': _EVALUATIONSTAGEMETRICS, '__module__': 'tensorflow.lite.tools.evaluation.proto.evaluation_config_pb2'})
_sym_db.RegisterMessage(EvaluationStageMetrics)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.profiler import profiler_options_pb2 as tensorflow_dot_core_dot_profiler_dot_profiler__options__pb2
from ....tensorflow.core.profiler import profiler_service_monitor_result_pb2 as tensorflow_dot_core_dot_profiler_dot_profiler__service__monitor__result__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/profiler_service.proto', package='tensorflow', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n/tensorflow/core/profiler/profiler_service.proto\x12\ntensorflow\x1a/tensorflow/core/profiler/profiler_options.proto\x1a>tensorflow/core/profiler/profiler_service_monitor_result.proto"B\n\x12ToolRequestOptions\x12\x16\n\x0eoutput_formats\x18\x02 \x01(\t\x12\x14\n\x0csave_to_repo\x18\x03 \x01(\x08"\xc9\x02\n\x0eProfileRequest\x12\x13\n\x0bduration_ms\x18\x01 \x01(\x04\x12\x12\n\nmax_events\x18\x02 \x01(\x04\x12\r\n\x05tools\x18\x03 \x03(\t\x12A\n\x0ctool_options\x18\x08 \x03(\x0b2+.tensorflow.ProfileRequest.ToolOptionsEntry\x12(\n\x04opts\x18\x04 \x01(\x0b2\x1a.tensorflow.ProfileOptions\x12\x17\n\x0frepository_root\x18\x05 \x01(\t\x12\x12\n\nsession_id\x18\x06 \x01(\t\x12\x11\n\thost_name\x18\x07 \x01(\t\x1aR\n\x10ToolOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12-\n\x05value\x18\x02 \x01(\x0b2\x1e.tensorflow.ToolRequestOptions:\x028\x01"-\n\x0fProfileToolData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04data\x18\x02 \x01(\x0c"t\n\x0fProfileResponse\x12.\n\ttool_data\x18\x06 \x03(\x0b2\x1b.tensorflow.ProfileToolData\x12\x13\n\x0bempty_trace\x18\x07 \x01(\x08J\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06"&\n\x10TerminateRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t"\x13\n\x11TerminateResponse"R\n\x0eMonitorRequest\x12\x13\n\x0bduration_ms\x18\x01 \x01(\x04\x12\x18\n\x10monitoring_level\x18\x02 \x01(\x05\x12\x11\n\ttimestamp\x18\x03 \x01(\x08"\x91\x01\n\x0fMonitorResponse\x12\x0c\n\x04data\x18\x01 \x01(\t\x12@\n\x0emonitor_result\x18\n \x01(\x0b2(.tensorflow.ProfilerServiceMonitorResultJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\tJ\x04\x08\t\x10\n2\xe9\x01\n\x0fProfilerService\x12D\n\x07Profile\x12\x1a.tensorflow.ProfileRequest\x1a\x1b.tensorflow.ProfileResponse"\x00\x12J\n\tTerminate\x12\x1c.tensorflow.TerminateRequest\x1a\x1d.tensorflow.TerminateResponse"\x00\x12D\n\x07Monitor\x12\x1a.tensorflow.MonitorRequest\x1a\x1b.tensorflow.MonitorResponse"\x00b\x06proto3', dependencies=[tensorflow_dot_core_dot_profiler_dot_profiler__options__pb2.DESCRIPTOR, tensorflow_dot_core_dot_profiler_dot_profiler__service__monitor__result__pb2.DESCRIPTOR])
_TOOLREQUESTOPTIONS = _descriptor.Descriptor(name='ToolRequestOptions', full_name='tensorflow.ToolRequestOptions', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='output_formats', full_name='tensorflow.ToolRequestOptions.output_formats', index=0, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='save_to_repo', full_name='tensorflow.ToolRequestOptions.save_to_repo', index=1, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=176, serialized_end=242)
_PROFILEREQUEST_TOOLOPTIONSENTRY = _descriptor.Descriptor(name='ToolOptionsEntry', full_name='tensorflow.ProfileRequest.ToolOptionsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.ProfileRequest.ToolOptionsEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.ProfileRequest.ToolOptionsEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=492, serialized_end=574)
_PROFILEREQUEST = _descriptor.Descriptor(name='ProfileRequest', full_name='tensorflow.ProfileRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='duration_ms', full_name='tensorflow.ProfileRequest.duration_ms', index=0, number=1, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='max_events', full_name='tensorflow.ProfileRequest.max_events', index=1, number=2, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tools', full_name='tensorflow.ProfileRequest.tools', index=2, number=3, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tool_options', full_name='tensorflow.ProfileRequest.tool_options', index=3, number=8, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='opts', full_name='tensorflow.ProfileRequest.opts', index=4, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='repository_root', full_name='tensorflow.ProfileRequest.repository_root', index=5, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='session_id', full_name='tensorflow.ProfileRequest.session_id', index=6, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_name', full_name='tensorflow.ProfileRequest.host_name', index=7, number=7, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_PROFILEREQUEST_TOOLOPTIONSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=245, serialized_end=574)
_PROFILETOOLDATA = _descriptor.Descriptor(name='ProfileToolData', full_name='tensorflow.ProfileToolData', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.ProfileToolData.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='data', full_name='tensorflow.ProfileToolData.data', index=1, number=2, type=12, cpp_type=9, label=1, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=576, serialized_end=621)
_PROFILERESPONSE = _descriptor.Descriptor(name='ProfileResponse', full_name='tensorflow.ProfileResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='tool_data', full_name='tensorflow.ProfileResponse.tool_data', index=0, number=6, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='empty_trace', full_name='tensorflow.ProfileResponse.empty_trace', index=1, number=7, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=623, serialized_end=739)
_TERMINATEREQUEST = _descriptor.Descriptor(name='TerminateRequest', full_name='tensorflow.TerminateRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_id', full_name='tensorflow.TerminateRequest.session_id', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=741, serialized_end=779)
_TERMINATERESPONSE = _descriptor.Descriptor(name='TerminateResponse', full_name='tensorflow.TerminateResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=781, serialized_end=800)
_MONITORREQUEST = _descriptor.Descriptor(name='MonitorRequest', full_name='tensorflow.MonitorRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='duration_ms', full_name='tensorflow.MonitorRequest.duration_ms', index=0, number=1, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='monitoring_level', full_name='tensorflow.MonitorRequest.monitoring_level', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='timestamp', full_name='tensorflow.MonitorRequest.timestamp', index=2, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=802, serialized_end=884)
_MONITORRESPONSE = _descriptor.Descriptor(name='MonitorResponse', full_name='tensorflow.MonitorResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='data', full_name='tensorflow.MonitorResponse.data', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='monitor_result', full_name='tensorflow.MonitorResponse.monitor_result', index=1, number=10, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=887, serialized_end=1032)
_PROFILEREQUEST_TOOLOPTIONSENTRY.fields_by_name['value'].message_type = _TOOLREQUESTOPTIONS
_PROFILEREQUEST_TOOLOPTIONSENTRY.containing_type = _PROFILEREQUEST
_PROFILEREQUEST.fields_by_name['tool_options'].message_type = _PROFILEREQUEST_TOOLOPTIONSENTRY
_PROFILEREQUEST.fields_by_name['opts'].message_type = tensorflow_dot_core_dot_profiler_dot_profiler__options__pb2._PROFILEOPTIONS
_PROFILERESPONSE.fields_by_name['tool_data'].message_type = _PROFILETOOLDATA
_MONITORRESPONSE.fields_by_name['monitor_result'].message_type = tensorflow_dot_core_dot_profiler_dot_profiler__service__monitor__result__pb2._PROFILERSERVICEMONITORRESULT
DESCRIPTOR.message_types_by_name['ToolRequestOptions'] = _TOOLREQUESTOPTIONS
DESCRIPTOR.message_types_by_name['ProfileRequest'] = _PROFILEREQUEST
DESCRIPTOR.message_types_by_name['ProfileToolData'] = _PROFILETOOLDATA
DESCRIPTOR.message_types_by_name['ProfileResponse'] = _PROFILERESPONSE
DESCRIPTOR.message_types_by_name['TerminateRequest'] = _TERMINATEREQUEST
DESCRIPTOR.message_types_by_name['TerminateResponse'] = _TERMINATERESPONSE
DESCRIPTOR.message_types_by_name['MonitorRequest'] = _MONITORREQUEST
DESCRIPTOR.message_types_by_name['MonitorResponse'] = _MONITORRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
ToolRequestOptions = _reflection.GeneratedProtocolMessageType('ToolRequestOptions', (_message.Message,), {'DESCRIPTOR': _TOOLREQUESTOPTIONS, '__module__': 'tensorflow.core.profiler.profiler_service_pb2'})
_sym_db.RegisterMessage(ToolRequestOptions)
ProfileRequest = _reflection.GeneratedProtocolMessageType('ProfileRequest', (_message.Message,), {'ToolOptionsEntry': _reflection.GeneratedProtocolMessageType('ToolOptionsEntry', (_message.Message,), {'DESCRIPTOR': _PROFILEREQUEST_TOOLOPTIONSENTRY, '__module__': 'tensorflow.core.profiler.profiler_service_pb2'}), 'DESCRIPTOR': _PROFILEREQUEST, '__module__': 'tensorflow.core.profiler.profiler_service_pb2'})
_sym_db.RegisterMessage(ProfileRequest)
_sym_db.RegisterMessage(ProfileRequest.ToolOptionsEntry)
ProfileToolData = _reflection.GeneratedProtocolMessageType('ProfileToolData', (_message.Message,), {'DESCRIPTOR': _PROFILETOOLDATA, '__module__': 'tensorflow.core.profiler.profiler_service_pb2'})
_sym_db.RegisterMessage(ProfileToolData)
ProfileResponse = _reflection.GeneratedProtocolMessageType('ProfileResponse', (_message.Message,), {'DESCRIPTOR': _PROFILERESPONSE, '__module__': 'tensorflow.core.profiler.profiler_service_pb2'})
_sym_db.RegisterMessage(ProfileResponse)
TerminateRequest = _reflection.GeneratedProtocolMessageType('TerminateRequest', (_message.Message,), {'DESCRIPTOR': _TERMINATEREQUEST, '__module__': 'tensorflow.core.profiler.profiler_service_pb2'})
_sym_db.RegisterMessage(TerminateRequest)
TerminateResponse = _reflection.GeneratedProtocolMessageType('TerminateResponse', (_message.Message,), {'DESCRIPTOR': _TERMINATERESPONSE, '__module__': 'tensorflow.core.profiler.profiler_service_pb2'})
_sym_db.RegisterMessage(TerminateResponse)
MonitorRequest = _reflection.GeneratedProtocolMessageType('MonitorRequest', (_message.Message,), {'DESCRIPTOR': _MONITORREQUEST, '__module__': 'tensorflow.core.profiler.profiler_service_pb2'})
_sym_db.RegisterMessage(MonitorRequest)
MonitorResponse = _reflection.GeneratedProtocolMessageType('MonitorResponse', (_message.Message,), {'DESCRIPTOR': _MONITORRESPONSE, '__module__': 'tensorflow.core.profiler.profiler_service_pb2'})
_sym_db.RegisterMessage(MonitorResponse)
_PROFILEREQUEST_TOOLOPTIONSENTRY._options = None
_PROFILERSERVICE = _descriptor.ServiceDescriptor(name='ProfilerService', full_name='tensorflow.ProfilerService', file=DESCRIPTOR, index=0, serialized_options=None, create_key=_descriptor._internal_create_key, serialized_start=1035, serialized_end=1268, methods=[_descriptor.MethodDescriptor(name='Profile', full_name='tensorflow.ProfilerService.Profile', index=0, containing_service=None, input_type=_PROFILEREQUEST, output_type=_PROFILERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='Terminate', full_name='tensorflow.ProfilerService.Terminate', index=1, containing_service=None, input_type=_TERMINATEREQUEST, output_type=_TERMINATERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='Monitor', full_name='tensorflow.ProfilerService.Monitor', index=2, containing_service=None, input_type=_MONITORREQUEST, output_type=_MONITORRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key)])
_sym_db.RegisterServiceDescriptor(_PROFILERSERVICE)
DESCRIPTOR.services_by_name['ProfilerService'] = _PROFILERSERVICE




'Generated protocol buffer code.'
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import tensor_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/summary.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\rSummaryProtosP\x01ZNgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/summary_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n\'tensorflow/core/framework/summary.proto\x12\ntensorflow\x1a&tensorflow/core/framework/tensor.proto"\'\n\x12SummaryDescription\x12\x11\n\ttype_hint\x18\x01 \x01(\t"\x87\x01\n\x0eHistogramProto\x12\x0b\n\x03min\x18\x01 \x01(\x01\x12\x0b\n\x03max\x18\x02 \x01(\x01\x12\x0b\n\x03num\x18\x03 \x01(\x01\x12\x0b\n\x03sum\x18\x04 \x01(\x01\x12\x13\n\x0bsum_squares\x18\x05 \x01(\x01\x12\x18\n\x0cbucket_limit\x18\x06 \x03(\x01B\x02\x10\x01\x12\x12\n\x06bucket\x18\x07 \x03(\x01B\x02\x10\x01"\xe0\x01\n\x0fSummaryMetadata\x12;\n\x0bplugin_data\x18\x01 \x01(\x0b2&.tensorflow.SummaryMetadata.PluginData\x12\x14\n\x0cdisplay_name\x18\x02 \x01(\t\x12\x1b\n\x13summary_description\x18\x03 \x01(\t\x12)\n\ndata_class\x18\x04 \x01(\x0e2\x15.tensorflow.DataClass\x1a2\n\nPluginData\x12\x13\n\x0bplugin_name\x18\x01 \x01(\t\x12\x0f\n\x07content\x18\x02 \x01(\x0c"\xde\x04\n\x07Summary\x12(\n\x05value\x18\x01 \x03(\x0b2\x19.tensorflow.Summary.Value\x1aX\n\x05Image\x12\x0e\n\x06height\x18\x01 \x01(\x05\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x12\n\ncolorspace\x18\x03 \x01(\x05\x12\x1c\n\x14encoded_image_string\x18\x04 \x01(\x0c\x1a}\n\x05Audio\x12\x13\n\x0bsample_rate\x18\x01 \x01(\x02\x12\x14\n\x0cnum_channels\x18\x02 \x01(\x03\x12\x15\n\rlength_frames\x18\x03 \x01(\x03\x12\x1c\n\x14encoded_audio_string\x18\x04 \x01(\x0c\x12\x14\n\x0ccontent_type\x18\x05 \x01(\t\x1a\xcf\x02\n\x05Value\x12\x11\n\tnode_name\x18\x07 \x01(\t\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12-\n\x08metadata\x18\t \x01(\x0b2\x1b.tensorflow.SummaryMetadata\x12\x16\n\x0csimple_value\x18\x02 \x01(\x02H\x00\x12&\n\x1cobsolete_old_style_histogram\x18\x03 \x01(\x0cH\x00\x12*\n\x05image\x18\x04 \x01(\x0b2\x19.tensorflow.Summary.ImageH\x00\x12+\n\x05histo\x18\x05 \x01(\x0b2\x1a.tensorflow.HistogramProtoH\x00\x12*\n\x05audio\x18\x06 \x01(\x0b2\x19.tensorflow.Summary.AudioH\x00\x12)\n\x06tensor\x18\x08 \x01(\x0b2\x17.tensorflow.TensorProtoH\x00B\x07\n\x05value*o\n\tDataClass\x12\x16\n\x12DATA_CLASS_UNKNOWN\x10\x00\x12\x15\n\x11DATA_CLASS_SCALAR\x10\x01\x12\x15\n\x11DATA_CLASS_TENSOR\x10\x02\x12\x1c\n\x18DATA_CLASS_BLOB_SEQUENCE\x10\x03B~\n\x18org.tensorflow.frameworkB\rSummaryProtosP\x01ZNgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/summary_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_tensor__pb2.DESCRIPTOR])
_DATACLASS = _descriptor.EnumDescriptor(name='DataClass', full_name='tensorflow.DataClass', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='DATA_CLASS_UNKNOWN', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='DATA_CLASS_SCALAR', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='DATA_CLASS_TENSOR', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='DATA_CLASS_BLOB_SEQUENCE', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1110, serialized_end=1221)
_sym_db.RegisterEnumDescriptor(_DATACLASS)
DataClass = enum_type_wrapper.EnumTypeWrapper(_DATACLASS)
DATA_CLASS_UNKNOWN = 0
DATA_CLASS_SCALAR = 1
DATA_CLASS_TENSOR = 2
DATA_CLASS_BLOB_SEQUENCE = 3
_SUMMARYDESCRIPTION = _descriptor.Descriptor(name='SummaryDescription', full_name='tensorflow.SummaryDescription', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='type_hint', full_name='tensorflow.SummaryDescription.type_hint', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=95, serialized_end=134)
_HISTOGRAMPROTO = _descriptor.Descriptor(name='HistogramProto', full_name='tensorflow.HistogramProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='min', full_name='tensorflow.HistogramProto.min', index=0, number=1, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='max', full_name='tensorflow.HistogramProto.max', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num', full_name='tensorflow.HistogramProto.num', index=2, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='sum', full_name='tensorflow.HistogramProto.sum', index=3, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='sum_squares', full_name='tensorflow.HistogramProto.sum_squares', index=4, number=5, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bucket_limit', full_name='tensorflow.HistogramProto.bucket_limit', index=5, number=6, type=1, cpp_type=5, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x10\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bucket', full_name='tensorflow.HistogramProto.bucket', index=6, number=7, type=1, cpp_type=5, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x10\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=137, serialized_end=272)
_SUMMARYMETADATA_PLUGINDATA = _descriptor.Descriptor(name='PluginData', full_name='tensorflow.SummaryMetadata.PluginData', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='plugin_name', full_name='tensorflow.SummaryMetadata.PluginData.plugin_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='content', full_name='tensorflow.SummaryMetadata.PluginData.content', index=1, number=2, type=12, cpp_type=9, label=1, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=449, serialized_end=499)
_SUMMARYMETADATA = _descriptor.Descriptor(name='SummaryMetadata', full_name='tensorflow.SummaryMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='plugin_data', full_name='tensorflow.SummaryMetadata.plugin_data', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='display_name', full_name='tensorflow.SummaryMetadata.display_name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='summary_description', full_name='tensorflow.SummaryMetadata.summary_description', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='data_class', full_name='tensorflow.SummaryMetadata.data_class', index=3, number=4, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_SUMMARYMETADATA_PLUGINDATA], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=275, serialized_end=499)
_SUMMARY_IMAGE = _descriptor.Descriptor(name='Image', full_name='tensorflow.Summary.Image', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='height', full_name='tensorflow.Summary.Image.height', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='width', full_name='tensorflow.Summary.Image.width', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='colorspace', full_name='tensorflow.Summary.Image.colorspace', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='encoded_image_string', full_name='tensorflow.Summary.Image.encoded_image_string', index=3, number=4, type=12, cpp_type=9, label=1, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=555, serialized_end=643)
_SUMMARY_AUDIO = _descriptor.Descriptor(name='Audio', full_name='tensorflow.Summary.Audio', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='sample_rate', full_name='tensorflow.Summary.Audio.sample_rate', index=0, number=1, type=2, cpp_type=6, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_channels', full_name='tensorflow.Summary.Audio.num_channels', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='length_frames', full_name='tensorflow.Summary.Audio.length_frames', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='encoded_audio_string', full_name='tensorflow.Summary.Audio.encoded_audio_string', index=3, number=4, type=12, cpp_type=9, label=1, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='content_type', full_name='tensorflow.Summary.Audio.content_type', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=645, serialized_end=770)
_SUMMARY_VALUE = _descriptor.Descriptor(name='Value', full_name='tensorflow.Summary.Value', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='node_name', full_name='tensorflow.Summary.Value.node_name', index=0, number=7, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tag', full_name='tensorflow.Summary.Value.tag', index=1, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='metadata', full_name='tensorflow.Summary.Value.metadata', index=2, number=9, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='simple_value', full_name='tensorflow.Summary.Value.simple_value', index=3, number=2, type=2, cpp_type=6, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='obsolete_old_style_histogram', full_name='tensorflow.Summary.Value.obsolete_old_style_histogram', index=4, number=3, type=12, cpp_type=9, label=1, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='image', full_name='tensorflow.Summary.Value.image', index=5, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='histo', full_name='tensorflow.Summary.Value.histo', index=6, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='audio', full_name='tensorflow.Summary.Value.audio', index=7, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor', full_name='tensorflow.Summary.Value.tensor', index=8, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='value', full_name='tensorflow.Summary.Value.value', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=773, serialized_end=1108)
_SUMMARY = _descriptor.Descriptor(name='Summary', full_name='tensorflow.Summary', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='value', full_name='tensorflow.Summary.value', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_SUMMARY_IMAGE, _SUMMARY_AUDIO, _SUMMARY_VALUE], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=502, serialized_end=1108)
_SUMMARYMETADATA_PLUGINDATA.containing_type = _SUMMARYMETADATA
_SUMMARYMETADATA.fields_by_name['plugin_data'].message_type = _SUMMARYMETADATA_PLUGINDATA
_SUMMARYMETADATA.fields_by_name['data_class'].enum_type = _DATACLASS
_SUMMARY_IMAGE.containing_type = _SUMMARY
_SUMMARY_AUDIO.containing_type = _SUMMARY
_SUMMARY_VALUE.fields_by_name['metadata'].message_type = _SUMMARYMETADATA
_SUMMARY_VALUE.fields_by_name['image'].message_type = _SUMMARY_IMAGE
_SUMMARY_VALUE.fields_by_name['histo'].message_type = _HISTOGRAMPROTO
_SUMMARY_VALUE.fields_by_name['audio'].message_type = _SUMMARY_AUDIO
_SUMMARY_VALUE.fields_by_name['tensor'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_SUMMARY_VALUE.containing_type = _SUMMARY
_SUMMARY_VALUE.oneofs_by_name['value'].fields.append(_SUMMARY_VALUE.fields_by_name['simple_value'])
_SUMMARY_VALUE.fields_by_name['simple_value'].containing_oneof = _SUMMARY_VALUE.oneofs_by_name['value']
_SUMMARY_VALUE.oneofs_by_name['value'].fields.append(_SUMMARY_VALUE.fields_by_name['obsolete_old_style_histogram'])
_SUMMARY_VALUE.fields_by_name['obsolete_old_style_histogram'].containing_oneof = _SUMMARY_VALUE.oneofs_by_name['value']
_SUMMARY_VALUE.oneofs_by_name['value'].fields.append(_SUMMARY_VALUE.fields_by_name['image'])
_SUMMARY_VALUE.fields_by_name['image'].containing_oneof = _SUMMARY_VALUE.oneofs_by_name['value']
_SUMMARY_VALUE.oneofs_by_name['value'].fields.append(_SUMMARY_VALUE.fields_by_name['histo'])
_SUMMARY_VALUE.fields_by_name['histo'].containing_oneof = _SUMMARY_VALUE.oneofs_by_name['value']
_SUMMARY_VALUE.oneofs_by_name['value'].fields.append(_SUMMARY_VALUE.fields_by_name['audio'])
_SUMMARY_VALUE.fields_by_name['audio'].containing_oneof = _SUMMARY_VALUE.oneofs_by_name['value']
_SUMMARY_VALUE.oneofs_by_name['value'].fields.append(_SUMMARY_VALUE.fields_by_name['tensor'])
_SUMMARY_VALUE.fields_by_name['tensor'].containing_oneof = _SUMMARY_VALUE.oneofs_by_name['value']
_SUMMARY.fields_by_name['value'].message_type = _SUMMARY_VALUE
DESCRIPTOR.message_types_by_name['SummaryDescription'] = _SUMMARYDESCRIPTION
DESCRIPTOR.message_types_by_name['HistogramProto'] = _HISTOGRAMPROTO
DESCRIPTOR.message_types_by_name['SummaryMetadata'] = _SUMMARYMETADATA
DESCRIPTOR.message_types_by_name['Summary'] = _SUMMARY
DESCRIPTOR.enum_types_by_name['DataClass'] = _DATACLASS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
SummaryDescription = _reflection.GeneratedProtocolMessageType('SummaryDescription', (_message.Message,), {'DESCRIPTOR': _SUMMARYDESCRIPTION, '__module__': 'tensorflow.core.framework.summary_pb2'})
_sym_db.RegisterMessage(SummaryDescription)
HistogramProto = _reflection.GeneratedProtocolMessageType('HistogramProto', (_message.Message,), {'DESCRIPTOR': _HISTOGRAMPROTO, '__module__': 'tensorflow.core.framework.summary_pb2'})
_sym_db.RegisterMessage(HistogramProto)
SummaryMetadata = _reflection.GeneratedProtocolMessageType('SummaryMetadata', (_message.Message,), {'PluginData': _reflection.GeneratedProtocolMessageType('PluginData', (_message.Message,), {'DESCRIPTOR': _SUMMARYMETADATA_PLUGINDATA, '__module__': 'tensorflow.core.framework.summary_pb2'}), 'DESCRIPTOR': _SUMMARYMETADATA, '__module__': 'tensorflow.core.framework.summary_pb2'})
_sym_db.RegisterMessage(SummaryMetadata)
_sym_db.RegisterMessage(SummaryMetadata.PluginData)
Summary = _reflection.GeneratedProtocolMessageType('Summary', (_message.Message,), {'Image': _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), {'DESCRIPTOR': _SUMMARY_IMAGE, '__module__': 'tensorflow.core.framework.summary_pb2'}), 'Audio': _reflection.GeneratedProtocolMessageType('Audio', (_message.Message,), {'DESCRIPTOR': _SUMMARY_AUDIO, '__module__': 'tensorflow.core.framework.summary_pb2'}), 'Value': _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), {'DESCRIPTOR': _SUMMARY_VALUE, '__module__': 'tensorflow.core.framework.summary_pb2'}), 'DESCRIPTOR': _SUMMARY, '__module__': 'tensorflow.core.framework.summary_pb2'})
_sym_db.RegisterMessage(Summary)
_sym_db.RegisterMessage(Summary.Image)
_sym_db.RegisterMessage(Summary.Audio)
_sym_db.RegisterMessage(Summary.Value)
DESCRIPTOR._options = None
_HISTOGRAMPROTO.fields_by_name['bucket_limit']._options = None
_HISTOGRAMPROTO.fields_by_name['bucket']._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/tensor_slice.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x11TensorSliceProtosP\x01ZSgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/tensor_slice_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n,tensorflow/core/framework/tensor_slice.proto\x12\ntensorflow"\x80\x01\n\x10TensorSliceProto\x123\n\x06extent\x18\x01 \x03(\x0b2#.tensorflow.TensorSliceProto.Extent\x1a7\n\x06Extent\x12\r\n\x05start\x18\x01 \x01(\x03\x12\x10\n\x06length\x18\x02 \x01(\x03H\x00B\x0c\n\nhas_lengthB\x87\x01\n\x18org.tensorflow.frameworkB\x11TensorSliceProtosP\x01ZSgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/tensor_slice_go_proto\xf8\x01\x01b\x06proto3')
_TENSORSLICEPROTO_EXTENT = _descriptor.Descriptor(name='Extent', full_name='tensorflow.TensorSliceProto.Extent', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='start', full_name='tensorflow.TensorSliceProto.Extent.start', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='length', full_name='tensorflow.TensorSliceProto.Extent.length', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='has_length', full_name='tensorflow.TensorSliceProto.Extent.has_length', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=134, serialized_end=189)
_TENSORSLICEPROTO = _descriptor.Descriptor(name='TensorSliceProto', full_name='tensorflow.TensorSliceProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='extent', full_name='tensorflow.TensorSliceProto.extent', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_TENSORSLICEPROTO_EXTENT], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=61, serialized_end=189)
_TENSORSLICEPROTO_EXTENT.containing_type = _TENSORSLICEPROTO
_TENSORSLICEPROTO_EXTENT.oneofs_by_name['has_length'].fields.append(_TENSORSLICEPROTO_EXTENT.fields_by_name['length'])
_TENSORSLICEPROTO_EXTENT.fields_by_name['length'].containing_oneof = _TENSORSLICEPROTO_EXTENT.oneofs_by_name['has_length']
_TENSORSLICEPROTO.fields_by_name['extent'].message_type = _TENSORSLICEPROTO_EXTENT
DESCRIPTOR.message_types_by_name['TensorSliceProto'] = _TENSORSLICEPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TensorSliceProto = _reflection.GeneratedProtocolMessageType('TensorSliceProto', (_message.Message,), {'Extent': _reflection.GeneratedProtocolMessageType('Extent', (_message.Message,), {'DESCRIPTOR': _TENSORSLICEPROTO_EXTENT, '__module__': 'tensorflow.core.framework.tensor_slice_pb2'}), 'DESCRIPTOR': _TENSORSLICEPROTO, '__module__': 'tensorflow.core.framework.tensor_slice_pb2'})
_sym_db.RegisterMessage(TensorSliceProto)
_sym_db.RegisterMessage(TensorSliceProto.Extent)
DESCRIPTOR._options = None
